@@ -12,6 +12,9 @@
 #' @references \url{http://uxblog.idvsolutions.com/2011/10/telling-truth.html},
 #'             \url{http://www.theusrus.de/blog/the-good-the-bad-22012/}
 #' @keywords aplot hplot color
+#' @importFrom grDevices colorRampPalette rainbow
+#' @importFrom graphics plot points segments
+#' @importFrom stats approx median na.omit
 #' @export
 #' @examples
 #' 
@@ -22,8 +25,8 @@
 #' # basic usage:
 #' colPoints(i,j,k, cex=1.5, pch="+", add=FALSE)
 #' 
-#' # with custom Range (only for method equalinterval):
-#' colPoints(i,j,k, cex=1.5, pch="+", add=FALSE, Range=c(150, 180))
+#' # with custom Range:
+#' colPoints(i,j,k, cex=1.5, pch="+", add=FALSE, Range=c(150, 190))
 #' # can be used to allow comparison between several plots
 #' # points outside the range are plotted with col2
 #' 
@@ -32,8 +35,8 @@
 #' colPoints(i,j,k, cex=1.5, pch="+", add=FALSE, col=mycols)
 #' 
 #' # With legend title:
-#' colPoints(i,j,k, cex=2, pch="+", add=FALSE,
-#'          legargs=list(density=FALSE, title="Elevation [m above NN.]"))
+#' colPoints(i,j,k, cex=2, add=FALSE, zlab="Elevation [m above NN.]",
+#'          legargs=list(density=FALSE))
 #' ?colPointsLegend # to see which arguments can be set via legargs
 #' 
 #' # with lines (nint to change number of linear interpolation points):
@@ -42,6 +45,8 @@
 #' tfile <- system.file("extdata/rivers.txt", package="berryFunctions")
 #' rivers <- read.table(tfile, header=TRUE, dec=",")
 #' colPoints(x,y,n, data=rivers, add=FALSE, lines=TRUE)
+#' colPoints(x,y,n, data=rivers, add=FALSE, lines=TRUE, pch=3)
+#' colPoints(x,y,n, data=rivers, add=FALSE, lines=TRUE, pch=3, nint=2)
 #' 
 #' # different classification methods:
 #' set.seed(007) ;  rx <- rnorm(30) ; ry <- rnorm(30) ; rz <- rnorm(30)*100
@@ -80,11 +85,10 @@
 #' 
 #' 
 #' # Customizing the legend :
-#' colPoints(i,j,k, legend=FALSE, add=FALSE)
+#' cp <- colPoints(i,j,k, legend=FALSE, add=FALSE)
 #' colPointsLegend(x1=20,y1=50, x2=95,y2=40, z=k, labelpos=5, atminmax=TRUE, bg=7)
 #' colPointsLegend(x1=50,y1=28, x2=90,y2=18, z=k, Range=c(80, 200), nbins=12, font=3)
 #' colPointsLegend(x1=10,y1=15, x2=40,y2= 5, z=k, labelpos=5, lines=FALSE, title="")
-#' 
 #' colPointsLegend(z=k, horizontal=FALSE)
 #' colPointsLegend(x1=1, y1=90, z=k, horizontal=FALSE, labelpos=4, cex=1.2)
 #' colPointsLegend(x1=23,y1=95, z=k, horizontal=FALSE, labelpos=5, cex=0.8,
@@ -92,7 +96,8 @@
 #' # For method other than colPoints' default, it is easiest to include these
 #' # options as a list in legargs, but you can also use the invisible output
 #' # from colPoints for later calls to colPointsLegend
-#' 
+#' do.call(colPointsLegend, cp)
+#' do.call(colPointsLegend, owa(cp, list(colors=rainbow2(100), cex=1.2)))
 #' 
 #' # colPoints with matrix:
 #' colPoints(z=volcano, add=FALSE)
@@ -116,54 +121,83 @@
 #' points(mx,my, cex=4)
 #' text(mx,my,mz, adj=-0.5, font=2)
 #' 
+#' # santiago.begueria.es/2010/10/generating-spatially-correlated-random-fields-with-r
+#' if(require(gstat)){
+#' xyz <- gstat(formula=z~1, locations=~x+y, dummy=TRUE, beta=1, 
+#'              model=vgm(psill=0.025,model="Exp",range=5), nmax=20)
+#' xyz <- predict(xyz, newdata=data.frame(x=runif(200, 20,40),y=runif(200, 50,70)), nsim=1)
+#' head(xyz)
+#' colPoints(x,y,sim1, data=xyz, col=rainbow2(100), add=FALSE)
+#' }
+#' 
 #' @param x,y Vectors with coordinates of the points to be drawn
-#' @param z z values beloning to coordinates. Vector or matrix
+#' @param z z values belonging to coordinates. Vector or matrix with the color-defining height values
 #' @param data Optional: data.frame with the column names as given by x,y and z.
-#' @param Range Ends of color bar for method=equalinterval. DEFAULT: range(z, finite=TRUE)
-#' @param method Classification method (partial matching is performed), see \code{\link{classify}}. DEFAULT: "equalinterval")
-#' @param breaks Specification for method, see \code{\link{classify}}. DEFAULT: different defaults for each method
-#' @param sdlab Type of label and breakpoints if \code{method=standarddeviation}, see \code{\link{classify}}. DEFAULT: 1
-#' @param col Vector of colors to be used. DEFAULT: \code{\link{rainbow}} from blue (lowest) to red (highest value in Range)
-#' @param col2 Color for points where z is NA, lower or higher than Range. DEFAULT: c(NA, 1, 8)
+#' @param add Logical. Should the points be added to current (existing!) plot? 
+#'            If FALSE, a new plot is started. DEFAULT: TRUE (It's called col\bold{Points}, after all)
+#' @param col Vector of colors to be used. DEFAULT: 100 colors from sequential 
+#'            palette \code{\link{seqPal}} (color-blind safe, black/white-print safe)
+#' @param col2 Color for points where z is NA, or lower / higher than \code{Range}. DEFAULT: c(NA, 1, 8)
+#' @param Range Ends of color bar. DEFAULT: range(z, finite=TRUE)
+#' @param method Classification method (partial matching is performed), 
+#'              see \code{\link{classify}} (ways to get color breakpoints). DEFAULT: "equalinterval")
+#' @param breaks Specification for method, see \code{\link{classify}}. 
+#'               DEFAULT: different defaults for each method
+#' @param sdlab Type of label and breakpoints if \code{method=standarddeviation}, 
+#'              see \code{\link{classify}}. DEFAULT: 1
 #' @param legend Logical. Should a \code{\link{colPointsLegend}} be drawn? DEFAULT: TRUE
-#' @param legargs List. Arguments passed to \code{\link{colPointsLegend}}. DEFAULT: NULL, with some defaults specified internally
-#' @param hist Logical. Should a \code{\link{colPointsHist}} be drawn? DEFAULT: FALSE (TRUE if histargs are given)
+#' @param legargs List. Arguments passed to \code{\link{colPointsLegend}}. 
+#'                DEFAULT: NULL, with some defaults specified internally
+#' @param hist Logical. Should a \code{\link{colPointsHist}} be drawn? 
+#'             DEFAULT: FALSE (TRUE if histargs are given)
 #' @param histargs List. Arguments passed to \code{\link{colPointsHist}}. DEFAULT: NULL
-#' @param add Logical. Should the points be added to current (existing!) plot? If FALSE, a new plot is started. DEFAULT: TRUE (It's called col\bold{Points}, after all)
-#' @param lines Logical. Should lines be drawn underneath the points? (color of each \code{\link{segments}} is taken from starting point, last point is endpoint.) DEFAULT: FALSE
-#' @param nint Numeric of length 1. Number of interpolation points between each coordinate if \code{lines=TRUE}. nint=1 means no interpolation. Values below 10 will smooth coordinates and miss the original points!. DEFAULT: 30
-#' @param xlab x-axis label. DEFAULT: substitute as in plot
+#' @param lines Logical. Should lines be drawn instead of / underneath the points? 
+#'             (color of each \code{\link{segments}} is taken from starting point, last point is endpoint.) 
+#'             If lines=TRUE and pch is not given, pch ist set to NA. DEFAULT: FALSE
+#' @param nint Numeric of length 1. Number of interpolation points between each 
+#'             coordinate if \code{lines=TRUE}. nint=1 means no interpolation. 
+#'             Values below 10 will smooth coordinates and might miss the original points. DEFAULT: 30
+#' @param xlab x-axis label. DEFAULT: \code{\link{substitute}(x)}
 #' @param ylab y-axis label. DEFAULT: ditto
-#' @param las Label Axis Style. Only used when add=FALSE. See \code{\link{par}}. DEFAULT: 1 (all labels horizontal)
+#' @param zlab \code{\link{colPointsLegend} title}. DEFAULT: ditto
+#' @param las Label Axis Style. Only used when add=FALSE. See \code{\link{par}}. 
+#'            DEFAULT: 1 (all labels horizontal)
 #' @param pch Point CHaracter. See \code{\link{par}}. DEFAULT: 16
 #' @param quiet Turn off warnings? DEFAULT: FALSE
-#' @param \dots Further graphical arguments passed to plot, points and lines, eg cex, xlim (when add=F), mgp, main, sub, asp (when add=F), etc. Note: col does not work, as it is already another argument
+#' @param \dots Further graphical arguments passed to \code{\link{plot}}, 
+#'              \code{\link{points}} and \code{\link{lines}}, 
+#'              eg cex, xlim (when add=F), mgp, main, sub, asp (when add=F), etc. 
+#'              Note: col does not work, as it is already another argument
 #' 
 colPoints <- function(
-  x, y, # x,y: Vectors with coordinates of the points to be drawn
-  z, # Vector or matrix with accompanying color defining height values
-  data, # Optional: data.frame with the column names as given by x,y and z.
-  Range=range(z, finite=TRUE), # Ends of color bar for method=equalinterval
-  method="equalinterval", # type of binning or classification method (ways to get color class breakpoints)
-  breaks, # specification for method
-  sdlab=1, #
-  col=seqPal(cl$nbins), # color palette. DEFAULT: 100 nuances from blue to red
-  col2=c(NA, 1, 8), # color for z==NA and points not in the color range
-  legend=TRUE, # Should a legend be drawn?
-  legargs=NULL, # Arguments for colPointsLegend.
-  hist=FALSE, # Should a legend be drawn?
-  histargs=NULL, # Arguments for colPointsHist. FALSE to suppress drawing
-  add=TRUE, # as in points. add to existing plot? add=F to draw new plot
-  lines=FALSE, #  Logical. Should lines be drawn underneath the points?
-  nint=30, # Numeric of length 1. Number of interpolation points between each coordinate if lines=TRUE.
-  xlab=substitute(x), # axis labels
+  x, y, 
+  z, 
+  data,
+  add=TRUE, 
+  col=seqPal(cl$nbins),
+  col2=c(NA, "grey", "black"),
+  Range=range(z, finite=TRUE), 
+  method="equalinterval",
+  breaks, 
+  sdlab=1, 
+  legend=TRUE, 
+  legargs=NULL, 
+  hist=FALSE, 
+  histargs=NULL, 
+  lines=FALSE, 
+  nint=30,
+  xlab=substitute(x),
   ylab=substitute(y),
-  las=1, # LabelAxisStyle: all labels horizontally (only relevant when add=FALSE)
-  pch=16, # PointCHaracter, see ?par
-  quiet=FALSE, # Turn off warnings?
-  ...) # further arguments passed to plot, points and lines, eg cex, xlim (bei add=F), mgp, main, sub, asp (when add=F), etc. NOT col
+  zlab=substitute(z),
+  las=1, 
+  pch=16, 
+  quiet=FALSE, 
+  ...)
 {
-xlab <- xlab ;  ylab <- ylab # defaults need to be set before x and y are evaluated
+ # default labels need to be obtained before x and y are evaluated
+xlab <- if(missing(xlab)) deparse(xlab) else xlab
+ylab <- if(missing(ylab)) deparse(ylab) else ylab
+zlab <- if(missing(zlab)) deparse(zlab) else zlab
 # error checking:
 if(length(nint)>1) if(!quiet) warning("Only the first value of 'nint' is used.")
 nint <- nint[1]
@@ -193,8 +227,8 @@ if(is.vector(z))
    } else
 # c) z is a matrix: class(z) = matrix, data.frame, array (2D) - as in image, persp
    {
-   if(missing(x)) {x <- 1:ncol(z) ; xlab <- "x" }
-   if(missing(y)) {y <- nrow(z):1 ; ylab <- "y" }
+   if(missing(x)) {x <- 1:ncol(z) ; if(missing(xlab)) xlab <- "x" }
+   if(missing(y)) {y <- nrow(z):1 ; if(missing(ylab)) ylab <- "y" }
    if(!(length(x)==ncol(z) & length(y)==nrow(z)))
      stop("Dimension of z (ncol*nrow) is not length(x) * length(y)!")
    x <- rep(x, each=nrow(z));  y <- rep(y, ncol(z));  z <- as.vector(z)
@@ -204,6 +238,10 @@ if(is.vector(z))
 if(method=="equalinterval") if(!missing(col)) breaks <- length(col)
 #
 cl <- classify(x=z, method=method, breaks=breaks, sdlab=sdlab, Range=Range, quiet=quiet)
+output <- cl
+output$x <- x
+output$y <- y
+output$z <- z
 # error check:
 if(length(col) != cl$nbins) stop("Number of colors is not equal to number of classes.")
 #
@@ -211,13 +249,19 @@ if(length(col) != cl$nbins) stop("Number of colors is not equal to number of cla
 if(!add) plot(x, y, col=NA, pch=pch, xlab=xlab, ylab=ylab, las=las, ...)
 # Plot lines if wanted:
 if(lines)
-  {# linear interpolation between coordinates (smoother line colors):
+  {
+  if(missing(pch)) pch <- NA
+  # linear interpolation between coordinates (smoother line colors):
   np <- length(x)*nint-nint+1 # replacing NA necessary if NAs are at start or end
-  x2 <- approx(replace(x, is.na(x), median(x, na.rm=TRUE)), n=np)$y
-  y2 <- approx(replace(y, is.na(y), median(y, na.rm=TRUE)), n=np)$y
-  z2 <- approx(replace(z, is.na(z), median(z, na.rm=TRUE)), n=np)$y
+  x2 <- approx2(x,n=np) #approx(replace(x, is.na(x), median(x, na.rm=TRUE)), n=np)$y
+  y2 <- approx2(y,n=np) #approx(replace(y, is.na(y), median(y, na.rm=TRUE)), n=np)$y
+  z2 <- approx2(z,n=np) #approx(replace(z, is.na(z), median(z, na.rm=TRUE)), n=np)$y
   # classify interpolated values:
   cl2 <- classify(x=z2, method=method, breaks=breaks, sdlab=sdlab, Range=Range, quiet=quiet)
+  output <- cl
+  output$x <- x2
+  output$y <- y2
+  output$z <- z2
   # Where are NAs in the vectors?
   wNA <- is.na(x) | is.na(y) | is.na(z)
   # change single values (surrounded by NA) to NA:
@@ -234,12 +278,11 @@ points(x[is.na(z)], y[is.na(z)], col=col2[1], pch=pch, ...)
 points(x, y, col=c(col, col2[2:3])[cl$index], pch=pch, ...)
 #
 # add legend:
-if(legend)
-  {
-  legdefs <- list(z=z, at=cl$at, labels=cl$labels, bb=cl$bb, nbins=cl$nbins,
-      colors=col, plottriangle=any(na.omit(cl$index>cl$nbins)), tricol=col2[2:3])
-  do.call(colPointsLegend, args=owa(legdefs, legargs))
-  }
+legdefs <- list(z=z, at=cl$at, labels=cl$labels, bb=cl$bb, nbins=cl$nbins,
+                plottriangle=c(any(na.omit(cl$index==cl$nbins+1)),any(na.omit(cl$index==cl$nbins+2))), 
+                title=zlab, tricol=col2[2:3], colors=col)
+output <- c(output, legdefs[!names(legdefs) %in% c("nbins","bb","at","labels","index","z")])
+if(legend) do.call(colPointsLegend, args=owa(legdefs, legargs))
 #
 # add histogramm:
 if(hist | !missing(histargs))
@@ -247,5 +290,5 @@ if(hist | !missing(histargs))
   histdefs <- list(z=z, at=cl$at, labels=cl$labels, bb=cl$bb, nbins=cl$nbins, colors=col)
   do.call(colPointsHist, args=owa(histdefs, histargs))
   }
-return(invisible(cl))
+return(invisible(output))
 } # Function end
