@@ -31,7 +31,7 @@ quiet=FALSE)
 {
 if(!(is.vector(a) & is.vector(b))) stop("input is not vectors")
 if(length(a) != length(b)) stop("vectors not of equal length")
-if(any(is.na(a)|is.na(b)))
+if( anyNA(a) | anyNA(b) )
    {
    Na <- which(is.na(a)|is.na(b))
    if(!quiet) warning(length(Na), " NAs were omitted from ", length(a), " data points.")
